| Title: | Profiling of Peripheral Blood Mononuclear Cells using CyTOF |
|---|---|
| Description: | This data package contains a subset of the Bodenmiller et al, Nat Biotech 2012 dataset for testing single cell, high dimensional analysis and visualization methods. |
| Authors: | Yann Abraham [aut, cre], Bernd Bodenmiller [aut] |
| Maintainer: | Yann Abraham <[email protected]> |
| License: | CC0 |
| Version: | 0.1.1 |
| Built: | 2026-05-28 06:09:55 UTC |
| Source: | https://github.com/yannabraham/bodenmiller |
A data.frame containing the source file and cell type for every cell in
refPhenoMat and refFuncMat. See
Bodenmiller et al 2012
for details.
refAnnotsrefAnnots
a data.frame with 15792 rows and 2 variables:
Sourcethe name of the source (fcs) file
Cellsthe cell type for the corresponding row in refPhenoMat
or refFuncMat
https://reports.cytobank.org/105/v2/
a matrix containing the signal intensity for functional markers measured using CyTOF
on different cell types. See
Bodenmiller et al 2012
for details.
refFuncMatrefFuncMat
a matrix with 15792 rows and 14 variables:
pStat1
pSlp76
pBtk
pPlcg2
pErk
pLat
pS6
pNFkB
pp38
pStat5
pAkt
pSHP2
pZap70
pStat3
https://reports.cytobank.org/105/v2/
a matrix containing the signal intensity for phenotypic markers measured using CyTOF
on different cell types. See
Bodenmiller et al 2012
for details.
refPhenoMatrefPhenoMat
a matrix with 15792 rows and 9 variables:
CD20
IgM
CD4
CD33
HLA-DR
CD14
CD7
CD3
CD123
https://reports.cytobank.org/105/v2/
A data.frame containing the source file, cell type and stimulation for every cell in
refPhenoMat and refFuncMat.
Stimulations include BCR/FcR-XL, PMA/Ionomycin and vanadate.See
Bodenmiller et al 2012
for details.
untreatedAnnotsuntreatedAnnots
a data.frame with 15792 rows and 2 variables:
Sourcethe name of the source (fcs) file
Treatmentthe treatment for the corresponding row in refPhenoMat
or refFuncMat
Cellsthe cell type for the corresponding row in refPhenoMat
or refFuncMat
https://reports.cytobank.org/105/v2/
a matrix containing the signal intensity for functional markers measured using CyTOF
on different cell types, after stimulation with BCR/FcR-XL, PMA/Ionomycin
and vanadate. See
Bodenmiller et al 2012
for details.
untreatedFuncMatuntreatedFuncMat
a matrix with 15792 rows and 14 variables:
pStat1
pSlp76
pBtk
pPlcg2
pErk
pLat
pS6
pNFkB
pp38
pStat5
pAkt
pSHP2
pZap70
pStat3
https://reports.cytobank.org/105/v2/
a matrix containing the signal intensity for phenotypic markers measured using CyTOF
on different cell types, after stimulation with BCR/FcR-XL, PMA/Ionomycin
and vanadate. See
Bodenmiller et al 2012
for details.
untreatedPhenoMatuntreatedPhenoMat
a matrix with 15792 rows and 9 variables:
CD20
IgM
CD4
CD33
HLA-DR
CD14
CD7
CD3
CD123
https://reports.cytobank.org/105/v2/